# -*- coding: utf-8 -*-
from A1_42 import *
from A1_48 import *


class A1_43(A1_42, A1_48):

    steps = []

    # Datos paso a242
    # ja tenim de les herències

    # Datos paso a2542
    # ja tenim de les herències

    # Datos paso a442
    # ja tenim de les herències

    # Datos paso a342
    # ja tenim de les herències

    # Datos paso a2s42
    # ja tenim de les herències

    # Datos paso a3s42
    # ja tenim de les herències

    # Datos paso a4s42
    # ja tenim de les herències

    @property
    def stateincidence(self):
        tree = '{0}.stateincidence'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def contact(self):
        tree = '{0}.contact'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return contact(data)
        else:
            return False


class contact(contact):

    @property
    def contacttelephone1(self):
        tree = 'contacttelephone1'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def contacttelephone2(self):
        tree = 'contacttelephone2'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def contacttelephone3(self):
        tree = 'contacttelephone3'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False



# -*- coding: utf-8 -*-
from message_gas import MessageGas
from Deadlines import ProcessDeadline, DeadLine, Workdays, Naturaldays
from gestionatr.utils import get_rec_attr
from A1_04 import *
from gestionatr.defs_gas import SUBTYPES_A1_48


class A1_48(A1_04):

    steps = []

    @property
    def claimertype(self):
        tree = '{0}.claimertype'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def claimer(self):
        tree = '{0}.claimer'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return claimer(data)
        else:
            return False

    @property
    def claimtype(self):
        tree = '{0}.claimtype'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def claimsubtype(self):
        tree = '{0}.claimsubtype'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def originreference(self):
        tree = '{0}.originreference'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def claimreferencelist(self):
        data = []
        obj = get_rec_attr(self.obj, self._header, False)
        if (hasattr(obj, 'claimreferencelist') and
                hasattr(obj.claimreferencelist, 'claimreference')):
            for d in obj.claimreferencelist.claimreference:
                data.append(claimreference(d))
        return data

    @property
    def legallimitdate(self):
        tree = '{0}.legallimitdate'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def priority(self):
        tree = '{0}.priority'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    # step a25
    @property
    def sequential(self):
        tree = '{0}.sequential'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def newclaimtype(self):
        tree = '{0}.newclaimtype'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def newclaimsubtype(self):
        tree = '{0}.newclaimsubtype'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def visitdate(self):
        tree = '{0}.visitdate'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def visithour(self):
        tree = '{0}.visithour'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def informationtype(self):
        tree = '{0}.informationtype'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def resultreasonintervention(self):
        tree = '{0}.resultreasonintervention'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def informationlist(self):
        data = []
        obj = get_rec_attr(self.obj, self._header, False)
        if (hasattr(obj, 'informationlist') and
                hasattr(obj.informationlist, 'information')):
            for d in obj.informationlist.information:
                data.append(information(d))
        return data

    # step a26
    @property
    def informationdate(self):
        tree = '{0}.informationdate'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def variableinflist(self):
        data = []
        obj = get_rec_attr(self.obj, self._header, False)
        if (hasattr(obj, 'variableinflist') and
                hasattr(obj.variableinflist, 'variableinf')):
            for d in obj.variableinflist.variableinf:
                data.append(variableinf(d))
        return data

    # step a3
    @property
    def resolutiondetail(self):
        tree = '{0}.resolutiondetail'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def resolutiondetaildesc(self):
        tree = '{0}.resolutiondetaildesc'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def creditedcompensation(self):
        tree = '{0}.creditedcompensation'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def anomalyfraudrecordnum(self):
        tree = '{0}.anomalyfraudrecordnum'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def movementdate(self):
        tree = '{0}.movementdate'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class variableinf(object):

    def __init__(self, data):
        self.obj = data

    @property
    def moreinformationtype(self):
        tree = 'moreinformationtype'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def description(self):
        tree = 'description'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def variabletype(self):
        tree = 'variabletype'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def variablevalue(self):
        tree = 'variablevalue'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False



class information(object):

    def __init__(self, data):
        self.obj = data

    @property
    def moreinformation(self):
        tree = 'moreinformation'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def moreinformationtype(self):
        tree = 'moreinformationtype'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def limitsenddate(self):
        tree = 'limitsenddate'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class client(object):

    def __init__(self, data):
        self.obj = data

    @property
    def document(self):
        tree = 'document'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return document(data)
        else:
            return False

    @property
    def titulartype(self):
        tree = 'titulartype'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def name(self):
        tree = 'name'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return name(data)
        else:
            return False

    @property
    def telephone(self):
        tree = 'telephone'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return telephone(data)
        else:
            return False

    @property
    def email(self):
        tree = 'email'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def clientaddress(self):
        tree = 'clientAddress'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return clientaddress(data)
        else:
            return False


class incidentperiod(object):

    def __init__(self, data):
        self.obj = data

    @property
    def datefrom(self):
        tree = 'datefrom'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def dateto(self):
        tree = 'dateto'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class name(object):

    def __init__(self, data):
        self.obj = data

    @property
    def firstname(self):
        tree = 'firstname'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def familyname1(self):
        tree = 'familyname1'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def familyname2(self):
        tree = 'familyname2'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def businessname(self):
        tree = 'businessname'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class reading(object):

    def __init__(self, data):
        self.obj = data

    @property
    def readingdate(self):
        tree = 'readingdate'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def readingvalue(self):
        tree = 'readingvalue'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class claimername(object):

    def __init__(self, data):
        self.obj = data

    @property
    def claimerfirstname(self):
        tree = 'claimerfirstname'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def claimerlastname(self):
        tree = 'claimerlastname'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def claimersecondname(self):
        tree = 'claimersecondname'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def claimerbusinessname(self):
        tree = 'claimerbusinessname'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class telephone(object):

    def __init__(self, data):
        self.obj = data

    @property
    def telephoneprefix(self):
        tree = 'telephoneprefix'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def telephonenumber(self):
        tree = 'telephonenumber'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class claimer(object):

    def __init__(self, data):
        self.obj = data

    @property
    def claimerid(self):
        tree = 'claimerid'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return claimerid(data)
        else:
            return False

    @property
    def claimername(self):
        tree = 'claimername'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return claimername(data)
        else:
            return False

    @property
    def claimertelephone(self):
        tree = 'claimertelephone'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return claimertelephone(data)
        else:
            return False

    @property
    def claimeremail(self):
        tree = 'claimeremail'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class contact(object):

    def __init__(self, data):
        self.obj = data

    @property
    def contactname(self):
        tree = 'contactname'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def contacttelephone(self):
        tree = 'contacttelephone'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return contacttelephone(data)
        else:
            return False

    @property
    def contactemail(self):
        tree = 'contactemail'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class incident(object):

    def __init__(self, data):
        self.obj = data

    @property
    def incidentdate(self):
        tree = 'incidentdate'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class claimertelephone(object):

    def __init__(self, data):
        self.obj = data

    @property
    def claimerprefixtel1(self):
        tree = 'claimerprefixtel1'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def claimertelephone1(self):
        tree = 'claimertelephone1'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class claimreference(object):

    def __init__(self, data):
        self.obj = data

    @property
    def numfactura(self):
        tree = 'numfactura'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def wrongattentiontype(self):
        tree = 'wrongattentiontype'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def comreferencenum(self):
        tree = 'comreferencenum'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def targetclaimcomreferencenum(self):
        tree = 'targetclaimcomreferencenum'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def conceptcontract(self):
        tree = 'conceptcontract'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def conceptfacturation(self):
        tree = 'conceptfacturation'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def contact(self):
        tree = 'contact'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return contact(data)
        else:
            return False

    @property
    def nnssexpedient(self):
        tree = 'nnssexpedient'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def fraudrecordnum(self):
        tree = 'fraudrecordnum'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def incidentperiod(self):
        tree = 'incidentperiod'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return incidentperiod(data)
        else:
            return False

    @property
    def invoicenumber(self):
        tree = 'invoicenumber'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def incidentlocation(self):
        tree = 'incidentlocation'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return incidentlocation(data)
        else:
            return False

    @property
    def reading(self):
        tree = 'reading'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return reading(data)
        else:
            return False

    @property
    def incident(self):
        tree = 'incident'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return incident(data)
        else:
            return False

    @property
    def client(self):
        tree = 'client'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return client(data)
        else:
            return False

    @property
    def claimedcompensation(self):
        tree = 'claimedcompensation'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def iban(self):
        tree = 'iban'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class incidentlocation(object):

    def __init__(self, data):
        self.obj = data

    @property
    def incidentlocationdesc(self):
        tree = 'incidentlocationdesc'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def incidentlocationprovince(self):
        tree = 'incidentlocationprovince'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def incidentlocationcity(self):
        tree = 'incidentlocationcity'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def incidentlocationcitysubdivision(self):
        tree = 'incidentlocationcitysubdivision'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def incidentlocationzipcode(self):
        tree = 'incidentlocationzipcode'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class contacttelephone(object):

    def __init__(self, data):
        self.obj = data

    @property
    def telephoneprefix(self):
        tree = 'telephoneprefix'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def telephonenumber(self):
        tree = 'telephonenumber'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def inventat(self):
        tree = 'inventat'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class clientaddress(object):

    def __init__(self, data):
        self.obj = data

    @property
    def province(self):
        tree = 'province'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def city(self):
        tree = 'city'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def zipcode(self):
        tree = 'zipcode'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def streettype(self):
        tree = 'streettype'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def street(self):
        tree = 'street'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def streetnumber(self):
        tree = 'streetnumber'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def portal(self):
        tree = 'portal'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def staircase(self):
        tree = 'staircase'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def floor(self):
        tree = 'floor'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def door(self):
        tree = 'door'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class claimerid(object):

    def __init__(self, data):
        self.obj = data

    @property
    def claimerdocumenttype(self):
        tree = 'claimerdocumenttype'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def claimerdocumentnum(self):
        tree = 'claimerdocumentnum'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


class claimreferencelist(object):

    def __init__(self, data):
        self.obj = data

    @property
    def claimreference(self):
        tree = 'claimreference'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return claimreference(data)
        else:
            return False


class document(object):

    def __init__(self, data):
        self.obj = data

    @property
    def documenttype(self):
        tree = 'documenttype'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def documentnum(self):
        tree = 'documentnum'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False


# Module Functions
def get_minimum_fields(r1_subtype):
    for x in SUBTYPES_A1_48:
        if x['code'] == r1_subtype:
            return x['min_fields']
    return []


def get_subtypes(r1_type):
    return [x['code'] for x in SUBTYPES_A1_48 if x['type'] == r1_type]


def get_type_from_subtype(r1_subtype):
    for x in SUBTYPES_A1_48:
        if x['code'] == r1_subtype:
            return x['type']
    return []


# -*- coding: utf-8 -*-
from gestionatr.output.messages.sw_c2 import *
from gestionatr.output.messages.base import CabeceraReclamacion


# Paso 01 
class MensajeReclamacionPeticion(XmlModel):

    _sort_order = ('mensaje', 'cabecera_reclamacion', 'solicitud_reclamacion')

    def __init__(self):
        self.mensaje = XmlField('MensajeReclamacionPeticion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera_reclamacion = CabeceraReclamacion()
        self.solicitud_reclamacion = SolicitudReclamacion()
        super(MensajeReclamacionPeticion, self).__init__('MensajeReclamacionPeticion', 'mensaje')


class SolicitudReclamacion(XmlModel):

    _sort_order = ('solicitud_reclamacion', 'datos_solicitud', 'variables_detalle_reclamacion', 'cliente', 'tipo_reclamante', 'reclamante', 'comentarios', 'registros_documento')

    def __init__(self):
        self.solicitud_reclamacion = XmlField('SolicitudReclamacion')
        self.datos_solicitud = DatosSolicitud()
        self.variables_detalle_reclamacion = VariablesDetalleReclamacion()
        self.cliente = Cliente()
        self.tipo_reclamante = XmlField('TipoReclamante')
        self.reclamante = Reclamante()
        self.comentarios = XmlField('Comentarios')
        self.registros_documento = RegistrosDocumento()
        super(SolicitudReclamacion, self).__init__('SolicitudReclamacion', 'solicitud_reclamacion')


class DatosSolicitud(XmlModel):

    _sort_order = ('datos_solicitud', 'tipo', 'subtipo', 'referencia_origen', 'fecha_limite', 'prioritario')

    def __init__(self):
        self.datos_solicitud = XmlField('DatosSolicitud')
        self.tipo = XmlField('Tipo')
        self.subtipo = XmlField('Subtipo')
        self.referencia_origen = XmlField('ReferenciaOrigen')
        self.fecha_limite = XmlField('FechaLimite')
        self.prioritario = XmlField('Prioritario')
        super(DatosSolicitud, self).__init__('DatosSolicitud', 'datos_solicitud')


class ParametrosComunicacion(XmlModel):

    _sort_order = ('parametros_comunicacion', 'cod_pm', 'cod_pm_principal', 'funcion', 'direccion_enlace',
                   'num_linea', 'clave_lectura', 'telefono', 'ip')

    def __init__(self):
        self.parametros_comunicacion = XmlField('ParametrosComunicacion')
        self.cod_pm = XmlField('CodPM')
        self.cod_pm_principal = XmlField('CodPMPrincipal')
        self.funcion = XmlField('Funcion')
        self.direccion_enlace = XmlField('DireccionEnlace')
        self.num_linea = XmlField('NumLinea')
        self.clave_lectura = XmlField('ClaveAcceso')
        self.telefono = TelefonoTelemedida()
        self.ip = IP()
        super(ParametrosComunicacion, self).__init__('ParametrosComunicacion', 'parametros_comunicacion')


class TelefonoTelemedida(XmlModel):

    _sort_order = ('telefono_telemedida', 'num_telefono', 'velocidad_comunicacion', 'bit_datos', 'paridad', 'bit_stop')

    def __init__(self):
        self.telefono_telemedida = XmlField('Telefono')
        self.num_telefono = XmlField('TelefonoTelemedida')
        self.velocidad_comunicacion = XmlField('VelocidadComunicacion')
        self.bit_datos = XmlField('BitDatos')
        self.paridad = XmlField('Paridad')
        self.bit_stop = XmlField('BitStop')
        super(TelefonoTelemedida, self).__init__('Telefono', 'telefono_telemedida')


class IP(XmlModel):

    _sort_order = ('ip', 'direccion_ip', 'puerto_enlace')

    def __init__(self):
        self.ip = XmlField('IP')
        self.direccion_ip = XmlField('DireccionIP')
        self.puerto_enlace = XmlField('PuertoEnlace')
        super(IP, self).__init__('IP', 'ip')


class VariablesDetalleReclamacion(XmlModel):

    _sort_order = ('variables_detalle_reclamacion', 'variable_detalle_reclamacion_list')

    def __init__(self):
        self.variables_detalle_reclamacion = XmlField('VariablesDetalleReclamacion')
        self.variable_detalle_reclamacion_list = []
        super(VariablesDetalleReclamacion, self).__init__('VariablesDetalleReclamacion', 'variables_detalle_reclamacion')


class VariableDetalleReclamacion(XmlModel):

    _sort_order = ('variable_detalle_reclamacion', 'num_expediente_acometida', 'num_expediente_fraude', 'fecha_incidente', 'num_factura_atr', 'tipo_concepto_facturado', 'fecha_lectura', 'tipo_dhedm', 'lecturas_aportadas', 'codigo_incidencia', 'codigo_solicitud', 'parametro_contratacion', 'concepto_disconformidad', 'tipo_de_atencion_incorrecta', 'iban', 'contacto', 'codigo_solicitud_reclamacion', 'fecha_desde', 'fecha_hasta', 'importe_reclamado', 'ubicacion_incidencia')

    def __init__(self):
        self.variable_detalle_reclamacion = XmlField('VariableDetalleReclamacion')
        self.num_expediente_acometida = XmlField('NumExpedienteAcometida')
        self.num_expediente_fraude = XmlField('NumExpedienteFraude')
        self.fecha_incidente = XmlField('FechaIncidente')
        self.num_factura_atr = XmlField('NumFacturaATR')
        self.tipo_concepto_facturado = XmlField('TipoConceptoFacturado')
        self.fecha_lectura = XmlField('FechaLectura')
        self.tipo_dhedm = XmlField('TipoDHEdM')
        self.lecturas_aportadas = LecturasAportadas()
        self.codigo_incidencia = XmlField('CodigoIncidencia')
        self.codigo_solicitud = XmlField('CodigoSolicitud')
        self.parametro_contratacion = XmlField('ParametroContratacion')
        self.concepto_disconformidad = XmlField('ConceptoDisconformidad')
        self.tipo_de_atencion_incorrecta = XmlField('TipoDeAtencionIncorrecta')
        self.iban = XmlField('IBAN')
        self.contacto = Contacto()
        self.codigo_solicitud_reclamacion = XmlField('CodigoSolicitudReclamacion')
        self.fecha_desde = XmlField('FechaDesde')
        self.fecha_hasta = XmlField('FechaHasta')
        self.importe_reclamado = XmlField('ImporteReclamado')
        self.ubicacion_incidencia = UbicacionIncidencia()
        super(VariableDetalleReclamacion, self).__init__('VariableDetalleReclamacion', 'variable_detalle_reclamacion')


class LecturasAportadas(XmlModel):

    _sort_order = ('lecturas_aportadas', 'lectura_aportada_list')

    def __init__(self):
        self.lecturas_aportadas = XmlField('LecturasAportadas')
        self.lectura_aportada_list = []
        super(LecturasAportadas, self).__init__('LecturasAportadas', 'lecturas_aportadas')


class LecturaAportada(XmlModel):

    _sort_order = ('lectura_aportada', 'integrador', 'codigo_periodo_dh', 'lectura_propuesta')

    def __init__(self):
        self.lectura_aportada = XmlField('LecturaAportada')
        self.integrador = XmlField('Integrador')
        self.codigo_periodo_dh = XmlField('CodigoPeriodoDH')
        self.lectura_propuesta = XmlField('LecturaPropuesta')
        super(LecturaAportada, self).__init__('LecturaAportada', 'lectura_aportada')


class UbicacionIncidencia(XmlModel):

    _sort_order = ('ubicacion_incidencia', 'des_ubicacion_incidencia', 'provincia', 'municipio', 'poblacion', 'cod_postal')

    def __init__(self):
        self.ubicacion_incidencia = XmlField('UbicacionIncidencia')
        self.des_ubicacion_incidencia = XmlField('DesUbicacionIncidencia')
        self.provincia = XmlField('Provincia')
        self.municipio = XmlField('Municipio')
        self.poblacion = XmlField('Poblacion')
        self.cod_postal = XmlField('CodPostal')
        super(UbicacionIncidencia, self).__init__('UbicacionIncidencia', 'ubicacion_incidencia')


class Reclamante(XmlModel):

    _sort_order = ('reclamante', 'id_reclamante', 'nombre', 'telefonos', 'correo_electronico')

    def __init__(self):
        self.reclamante = XmlField('Reclamante')
        self.id_reclamante = IdReclamante()
        self.nombre = Nombre()
        self.telefonos = []
        self.correo_electronico = XmlField('CorreoElectronico')
        super(Reclamante, self).__init__('Reclamante', 'reclamante')


class IdReclamante(XmlModel):

    _sort_order = ('id_reclamante', 'tipo_identificador', 'identificador')

    def __init__(self):
        self.id_reclamante = XmlField('IdReclamante')
        self.tipo_identificador = XmlField('TipoIdentificador')
        self.identificador = XmlField('Identificador')
        super(IdReclamante, self).__init__('IdReclamante', 'id_reclamante')


# Paso 02
class MensajeAceptacionReclamacion(XmlModel):

    _sort_order = ('mensaje', 'cabecera_reclamacion', 'aceptacion_reclamacion')

    def __init__(self):
        self.mensaje = XmlField('MensajeAceptacionReclamacion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera_reclamacion = CabeceraReclamacion()
        self.aceptacion_reclamacion = AceptacionReclamacion()
        super(MensajeAceptacionReclamacion, self).__init__('MensajeAceptacionReclamacion', 'mensaje')


class AceptacionReclamacion(XmlModel):

    _sort_order = ('aceptacion_reclamacion', 'datos_aceptacion')

    def __init__(self):
        self.aceptacion_reclamacion = XmlField('AceptacionReclamacion')
        self.datos_aceptacion = DatosAceptacion()
        super(AceptacionReclamacion, self).__init__('AceptacionReclamacion', 'aceptacion_reclamacion')


class DatosAceptacion(XmlModel):

    _sort_order = ('datos_aceptacion', 'fecha_aceptacion', 'codigo_reclamacion_distribuidora')

    def __init__(self):
        self.datos_aceptacion = XmlField('DatosAceptacion')
        self.fecha_aceptacion = XmlField('FechaAceptacion')
        self.codigo_reclamacion_distribuidora = XmlField('CodigoReclamacionDistribuidora')
        super(DatosAceptacion, self).__init__('DatosAceptacion', 'datos_aceptacion')


# Rechazo Reclamacion
class MensajeRechazoReclamacion(XmlModel):

    _sort_order = ('mensaje_rechazo_reclamacion', 'cabecera_reclamacion', 'rechazos')

    def __init__(self):
        self.mensaje_rechazo_reclamacion = XmlField('MensajeRechazoReclamacion',
                                        attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera_reclamacion = CabeceraReclamacion()
        self.rechazos = Rechazos()
        super(MensajeRechazoReclamacion, self).__init__('MensajeRechazoReclamacion', 'mensaje_rechazo_reclamacion')


# Paso 03
class MensajePeticionInformacionAdicionalReclamacion(XmlModel):

    _sort_order = ('mensaje', 'cabecera_reclamacion', 'informacion_adicional')

    def __init__(self):
        self.mensaje = XmlField('MensajePeticionInformacionAdicionalReclamacion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera_reclamacion = CabeceraReclamacion()
        self.informacion_adicional = InformacionAdicional()
        super(MensajePeticionInformacionAdicionalReclamacion, self).__init__('MensajePeticionInformacionAdicionalReclamacion', 'mensaje')


class InformacionAdicional(XmlModel):

    _sort_order = ('informacion_adicional', 'datos_informacion', 'informacion_intermedia', 'retipificacion', 'solicitudes_informacion_adicional', 'comentarios', 'parametros_comunicacion', 'registros_documento')

    def __init__(self):
        self.informacion_adicional = XmlField('InformacionAdicional')
        self.datos_informacion = DatosInformacion()
        self.informacion_intermedia = InformacionIntermedia()
        self.retipificacion = Retipificacion()
        self.solicitudes_informacion_adicional = SolicitudesInformacionAdicional()
        self.comentarios = XmlField('Comentarios')
        self.parametros_comunicacion = ParametrosComunicacion()
        self.registros_documento = RegistrosDocumento()
        super(InformacionAdicional, self).__init__('InformacionAdicional', 'informacion_adicional')


class DatosInformacion(XmlModel):

    _sort_order = ('datos_informacion', 'num_expediente_acometida', 'tipo_comunicacion', 'codigo_reclamacion_distribuidora')

    def __init__(self):
        self.datos_informacion = XmlField('DatosInformacion')
        self.num_expediente_acometida = XmlField('NumExpedienteAcometida')
        self.tipo_comunicacion = XmlField('TipoComunicacion')
        self.codigo_reclamacion_distribuidora = XmlField('CodigoReclamacionDistribuidora')
        super(DatosInformacion, self).__init__('DatosInformacion', 'datos_informacion')


class InformacionIntermedia(XmlModel):

    _sort_order = ('informacion_intermedia', 'desc_informacion_intermedia', 'intervenciones')

    def __init__(self):
        self.informacion_intermedia = XmlField('InformacionIntermedia')
        self.desc_informacion_intermedia = XmlField('DescInformacionIntermedia')
        self.intervenciones = Intervenciones()
        super(InformacionIntermedia, self).__init__('InformacionIntermedia', 'informacion_intermedia')


class Intervenciones(XmlModel):

    _sort_order = ('intervenciones', 'intervencion_list')

    def __init__(self):
        self.intervenciones = XmlField('Intervenciones')
        self.intervencion_list = []
        super(Intervenciones, self).__init__('Intervenciones', 'intervenciones')


class Intervencion(XmlModel):

    _sort_order = ('intervencion', 'tipo_intervencion', 'fecha', 'hora_desde', 'hora_hasta', 'numero_visita', 'resultado', 'detalle_resultado')

    def __init__(self):
        self.intervencion = XmlField('Intervencion')
        self.tipo_intervencion = XmlField('TipoIntervencion')
        self.fecha = XmlField('Fecha')
        self.hora_desde = XmlField('HoraDesde')
        self.hora_hasta = XmlField('HoraHasta')
        self.numero_visita = XmlField('NumeroVisita')
        self.resultado = XmlField('Resultado')
        self.detalle_resultado = XmlField('DetalleResultado')
        super(Intervencion, self).__init__('Intervencion', 'intervencion')


class Retipificacion(XmlModel):

    _sort_order = ('retipificacion', 'tipo', 'subtipo', 'desc_retipificacion')

    def __init__(self):
        self.retipificacion = XmlField('Retipificacion')
        self.tipo = XmlField('Tipo')
        self.subtipo = XmlField('Subtipo')
        self.desc_retipificacion = XmlField('DescRetipificacion')
        super(Retipificacion, self).__init__('Retipificacion', 'retipificacion')


class SolicitudesInformacionAdicional(XmlModel):

    _sort_order = ('solicitudes_informacion_adicional', 'solicitud_informacion_adicional_list', 'solicitud_informacion_adicional_para_retipificacion')

    def __init__(self):
        self.solicitudes_informacion_adicional = XmlField('SolicitudesInformacionAdicional')
        self.solicitud_informacion_adicional_list = []
        self.solicitud_informacion_adicional_para_retipificacion = SolicitudInformacionAdicionalParaRetipificacion()
        super(SolicitudesInformacionAdicional, self).__init__('SolicitudesInformacionAdicional', 'solicitudes_informacion_adicional')


class SolicitudInformacionAdicional(XmlModel):

    _sort_order = ('solicitud_informacion_adicional', 'tipo_informacion_adicional', 'desc_peticion_informacion', 'fecha_limite_envio')

    def __init__(self):
        self.solicitud_informacion_adicional = XmlField('SolicitudInformacionAdicional')
        self.tipo_informacion_adicional = XmlField('TipoInformacionAdicional')
        self.desc_peticion_informacion = XmlField('DescPeticionInformacion')
        self.fecha_limite_envio = XmlField('FechaLimiteEnvio')
        super(SolicitudInformacionAdicional, self).__init__('SolicitudInformacionAdicional', 'solicitud_informacion_adicional')


class SolicitudInformacionAdicionalParaRetipificacion(XmlModel):

    _sort_order = ('solicitud_informacion_adicional_para_retipificacion', 'tipo', 'subtipo', 'fecha_limite_envio')

    def __init__(self):
        self.solicitud_informacion_adicional_para_retipificacion = XmlField('SolicitudInformacionAdicionalParaRetipificacion')
        self.tipo = XmlField('Tipo')
        self.subtipo = XmlField('Subtipo')
        self.fecha_limite_envio = XmlField('FechaLimiteEnvio')
        super(SolicitudInformacionAdicionalParaRetipificacion, self).__init__('SolicitudInformacionAdicionalParaRetipificacion', 'solicitud_informacion_adicional_para_retipificacion')


# Paso 04
class MensajeEnvioInformacionReclamacion(XmlModel):

    _sort_order = ('mensaje', 'cabecera_reclamacion', 'envio_informacion_reclamacion')

    def __init__(self):
        self.mensaje = XmlField('MensajeEnvioInformacionReclamacion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera_reclamacion = CabeceraReclamacion()
        self.envio_informacion_reclamacion = EnvioInformacionReclamacion()
        super(MensajeEnvioInformacionReclamacion, self).__init__('MensajeEnvioInformacionReclamacion', 'mensaje')


class EnvioInformacionReclamacion(XmlModel):

    _sort_order = ('envio_informacion_reclamacion', 'datos_envio_informacion', 'variables_aportacion_informacion', 'variables_aportacion_informacion_para_retipificacion', 'cliente', 'comentarios', 'registros_documento')

    def __init__(self):
        self.envio_informacion_reclamacion = XmlField('EnvioInformacionReclamacion')
        self.datos_envio_informacion = DatosEnvioInformacion()
        self.variables_aportacion_informacion = VariablesAportacionInformacion()
        self.variables_aportacion_informacion_para_retipificacion = VariablesAportacionInformacionParaRetipificacion()
        self.cliente = Cliente()
        self.comentarios = XmlField('Comentarios')
        self.registros_documento = RegistrosDocumento()
        super(EnvioInformacionReclamacion, self).__init__('EnvioInformacionReclamacion', 'envio_informacion_reclamacion')


class DatosEnvioInformacion(XmlModel):

    _sort_order = ('datos_envio_informacion', 'num_expediente_acometida', 'fecha_informacion')

    def __init__(self):
        self.datos_envio_informacion = XmlField('DatosEnvioInformacion')
        self.num_expediente_acometida = XmlField('NumExpedienteAcometida')
        self.fecha_informacion = XmlField('FechaInformacion')
        super(DatosEnvioInformacion, self).__init__('DatosEnvioInformacion', 'datos_envio_informacion')


class VariablesAportacionInformacion(XmlModel):

    _sort_order = ('variables_aportacion_informacion', 'variable_aportacion_informacion_list')

    def __init__(self):
        self.variables_aportacion_informacion = XmlField('VariablesAportacionInformacion')
        self.variable_aportacion_informacion_list = []
        super(VariablesAportacionInformacion, self).__init__('VariablesAportacionInformacion', 'variables_aportacion_informacion')


class VariableAportacionInformacion(XmlModel):

    _sort_order = ('variable_aportacion_informacion', 'tipo_informacion', 'desc_peticion_informacion', 'variable', 'valor')

    def __init__(self):
        self.variable_aportacion_informacion = XmlField('VariableAportacionInformacion')
        self.tipo_informacion = XmlField('TipoInformacion')
        self.desc_peticion_informacion = XmlField('DescPeticionInformacion')
        self.variable = XmlField('Variable')
        self.valor = XmlField('Valor')
        super(VariableAportacionInformacion, self).__init__('VariableAportacionInformacion', 'variable_aportacion_informacion')


class VariablesAportacionInformacionParaRetipificacion(XmlModel):

    _sort_order = ('variables_aportacion_informacion_para_retipificacion', 'variable_aportacion_informacion_para_retipificacion_list')

    def __init__(self):
        self.variables_aportacion_informacion_para_retipificacion = XmlField('VariablesAportacionInformacionParaRetipificacion')
        self.variable_aportacion_informacion_para_retipificacion_list = []
        super(VariablesAportacionInformacionParaRetipificacion, self).__init__('VariablesAportacionInformacionParaRetipificacion', 'variables_aportacion_informacion_para_retipificacion')


class VariableAportacionInformacionParaRetipificacion(XmlModel):

    _sort_order = ('variable_aportacion_informacion_para_retipificacion', 'num_expediente_acometida', 'num_expediente_fraude', 'fecha_incidente', 'num_factura_atr', 'tipo_concepto_facturado', 'fecha_lectura', 'tipo_dhedm', 'lecturas_aportadas', 'codigo_incidencia', 'codigo_solicitud', 'parametro_contratacion', 'concepto_disconformidad', 'tipo_de_atencion_incorrecta', 'iban', 'contacto', 'codigo_solicitud_reclamacion', 'fecha_desde', 'fecha_hasta', 'importe_reclamado', 'ubicacion_incidencia')

    def __init__(self):
        self.variable_aportacion_informacion_para_retipificacion = XmlField('VariableAportacionInformacionParaRetipificacion')
        self.num_expediente_acometida = XmlField('NumExpedienteAcometida')
        self.num_expediente_fraude = XmlField('NumExpedienteFraude')
        self.fecha_incidente = XmlField('FechaIncidente')
        self.num_factura_atr = XmlField('NumFacturaATR')
        self.tipo_concepto_facturado = XmlField('TipoConceptoFacturado')
        self.fecha_lectura = XmlField('FechaLectura')
        self.tipo_dhedm = XmlField('TipoDHEdM')
        self.lecturas_aportadas = LecturasAportadas()
        self.codigo_incidencia = XmlField('CodigoIncidencia')
        self.codigo_solicitud = XmlField('CodigoSolicitud')
        self.parametro_contratacion = XmlField('ParametroContratacion')
        self.concepto_disconformidad = XmlField('ConceptoDisconformidad')
        self.tipo_de_atencion_incorrecta = XmlField('TipoDeAtencionIncorrecta')
        self.iban = XmlField('IBAN')
        self.contacto = Contacto()
        self.codigo_solicitud_reclamacion = XmlField('CodigoSolicitudReclamacion')
        self.fecha_desde = XmlField('FechaDesde')
        self.fecha_hasta = XmlField('FechaHasta')
        self.importe_reclamado = XmlField('ImporteReclamado')
        self.ubicacion_incidencia = UbicacionIncidencia()
        super(VariableAportacionInformacionParaRetipificacion, self).__init__('VariableAportacionInformacionParaRetipificacion', 'variable_aportacion_informacion_para_retipificacion')


# Paso 05
class MensajeCierreReclamacion(XmlModel):

    _sort_order = ('mensaje_cierre_reclamacion', 'cabecera_reclamacion', 'cierre_reclamacion')

    def __init__(self):
        self.mensaje = XmlField('MensajeCierreReclamacion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera_reclamacion = CabeceraReclamacion()
        self.cierre_reclamacion = CierreReclamacion()
        super(MensajeCierreReclamacion, self).__init__('MensajeCierreReclamacion', 'mensaje')


class CierreReclamacion(XmlModel):

    _sort_order = ('cierre_reclamacion', 'datos_cierre',  'parametros_comunicacion', 'cod_contrato', 'comentarios', 'registros_documento')

    def __init__(self):
        self.cierre_reclamacion = XmlField('CierreReclamacion')
        self.datos_cierre = DatosCierre()
        self.cod_contrato = XmlField('CodContrato')
        self.comentarios = XmlField('Comentarios')
        self.parametros_comunicacion = ParametrosComunicacion()
        self.registros_documento = RegistrosDocumento()
        super(CierreReclamacion, self).__init__('CierreReclamacion', 'cierre_reclamacion')


class DatosCierre(XmlModel):

    _sort_order = ('datos_cierre', 'num_expediente_acometida', 'fecha', 'hora', 'tipo', 'subtipo', 'codigo_reclamacion_distribuidora', 'resultado_reclamacion', 'detalle_resultado', 'observaciones', 'indemnizacion_abonada', 'num_expediente_anomalia_fraude', 'fecha_movimiento')

    def __init__(self):
        self.datos_cierre = XmlField('DatosCierre')
        self.num_expediente_acometida = XmlField('NumExpedienteAcometida')
        self.fecha = XmlField('Fecha')
        self.hora = XmlField('Hora')
        self.tipo = XmlField('Tipo')
        self.subtipo = XmlField('Subtipo')
        self.codigo_reclamacion_distribuidora = XmlField('CodigoReclamacionDistribuidora')
        self.resultado_reclamacion = XmlField('ResultadoReclamacion')
        self.detalle_resultado = XmlField('DetalleResultado')
        self.observaciones = XmlField('Observaciones')
        self.indemnizacion_abonada = XmlField('IndemnizacionAbonada')
        self.num_expediente_anomalia_fraude = XmlField('NumExpedienteAnomaliaFraude')
        self.fecha_movimiento = XmlField('FechaMovimiento')
        super(DatosCierre, self).__init__('DatosCierre', 'datos_cierre')


# Paso 08
class MensajeAnulacionSolicitudReclamacion(XmlModel):

    _sort_order = ('mensaje', 'cabecera_reclamacion')

    def __init__(self):
        self.mensaje = XmlField('MensajeAnulacionSolicitudReclamacion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera_reclamacion = CabeceraReclamacion()
        super(MensajeAnulacionSolicitudReclamacion, self).__init__('MensajeAnulacionSolicitudReclamacion', 'mensaje')


# Paso 09
class MensajeAceptacionAnulacionReclamacion(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'aceptacion_anulacion')

    def __init__(self):
        self.mensaje = XmlField('MensajeAceptacionAnulacionReclamacion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.aceptacion_anulacion = AceptacionAnulacion()
        super(MensajeAceptacionAnulacionReclamacion, self).__init__('MensajeAceptacionAnulacionReclamacion', 'mensaje')



# -*- coding: utf-8 -*-

from C2 import C2, DatosSolicitud, Contacto
from C1 import DatosAceptacion
from Deadlines import ProcessDeadline, DeadLine, Workdays, Naturaldays
from gestionatr.utils import get_rec_attr


class B1(C2):
    """Classe que implementa B1."""

    steps_01 = [
        DeadLine('00', Workdays(-5)),
        DeadLine('01', Workdays(5)),
        DeadLine('02', Workdays(1)),
        DeadLine('03', Workdays(5)),
        DeadLine('05', Workdays(1)),
    ]

    steps_02 = [
        DeadLine('00', Workdays(-15)),
        DeadLine('01', Workdays(5)),
        DeadLine('02', Workdays(1)),
        DeadLine('03', Workdays(5)),
        DeadLine('05', Workdays(1)),
    ]

    steps_03 = [
        DeadLine('02', Naturaldays(60)),
        DeadLine('03', Workdays(1)),
        DeadLine('05', Naturaldays(60)),
    ]

    steps_04 = steps_01

    steps = steps_01

    # Datos paso 01
    @property
    def datos_solicitud(self):
        tree = '{0}.DatosSolicitud'.format(self._header)
        sol = get_rec_attr(self.obj, tree, False)
        if sol not in [None, False]:
            return DatosSolicitud(sol)
        else:
            return False

    @property
    def iban(self):
        tree = '{0}.IBAN'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def contacto(self):
        tree = '{0}.Contacto'.format(self._header)
        cli = get_rec_attr(self.obj, tree, False)
        if cli not in [None, False]:
            return Contacto(cli)
        else:
            return False

    # Datos paso 02
    @property
    def datos_aceptacion(self):
        tree = '{0}.DatosAceptacion'.format(self._header)
        sol = get_rec_attr(self.obj, tree, False)
        if sol not in [None, False]:
            return DatosAceptacion(sol)
        else:
            return False

    # Datos paso 04
    @property
    def hora_aceptacion(self):
        tree = '{0}.HoraAceptacion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    # Datos paso 05
    @property
    def datos_activacion_baja(self):
        tree = '{0}.DatosActivacionBaja'.format(self._header)
        sol = get_rec_attr(self.obj, tree, False)
        if sol not in [None, False]:
            return DatosActivacionBaja(sol)
        else:
            return False


class DatosSolicitud(DatosSolicitud):

    @property
    def motivo(self):
        data = ''
        try:
            data = self.datos_solicitud.Motivo.text
        except AttributeError:
            pass
        return data


class DatosAceptacion(DatosAceptacion):

    @property
    def tipo_activacion_prevista(self):
        data = ''
        try:
            data = self.datos_aceptacion.TipoActivacionPrevista.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_activacion_prevista(self):
        data = False
        try:
            data = self.datos_aceptacion.FechaActivacionPrevista.text
        except AttributeError:
            pass
        return data


class DatosActivacionBaja(object):

    def __init__(self, data):
        self.datos_activacion_baja = data

    @property
    def fecha_activacion(self):
        data = False
        try:
            data = self.datos_activacion_baja.FechaActivacion.text
        except AttributeError:
            pass
        return data



# -*- coding: utf-8 -*-

from libcomxml.core import XmlModel, XmlField
from gestionatr.output.messages.base_gas import Heading
from gestionatr.output.messages.sw_a1_41 import Registerdoclist, Registerdoc
from gestionatr.output.messages.sw_a1_42 import ProductList, Product


# Paso 01
class MensajeA138(XmlModel):
    _sort_order = ('mensaje', 'heading', 'a138')

    def __init__(self):
        self.doc_root = None
        self.mensaje = XmlField(
            'sctdapplication', attributes={'xmlns': 'http://localhost/sctd/A138'}
        )
        self.heading = Heading()
        self.a138 = A138()
        super(MensajeA138, self).__init__('sctdapplication', 'mensaje')


class A138(XmlModel):

    _sort_order = (
        'a138', 'comreferencenum', 'reqdate', 'reqhour', 'titulartype', 'nationality', 'documenttype', 'documentnum',
        'firstname', 'familyname1', 'familyname2', 'telephone1', 'telephone2', 'fax', 'email', 'language', 'province',
        'city', 'zipcode', 'streettype', 'street', 'streetnumber', 'portal', 'staircase', 'floor', 'door',
        'regularaddress', 'provinceowner', 'cityowner', 'zipcodeowner', 'streettypeowner', 'streetowner',
        'streetnumberowner', 'portalowner', 'staircaseowner', 'floorowner', 'doorowner', 'cups', 'reqqd', 'reqqh',
        'reqestimatedqa', 'reqoutgoingpressure', 'gasusetype', 'tolltype', 'counterproperty', 'aptransind',
        'aptransnumber', 'reig', 'designpower', 'iricertificatedate', 'terminstexist', 'modeffectdate',
        'reqactivationdate', 'extrainfo', 'productlist', 'registerdoclist'
    )

    def __init__(self):
        self.a138 = XmlField('a138')
        self.comreferencenum = XmlField('comreferencenum')
        self.reqdate = XmlField('reqdate')
        self.reqhour = XmlField('reqhour')
        self.titulartype = XmlField('titulartype')
        self.nationality = XmlField('nationality')
        self.documenttype = XmlField('documenttype')
        self.documentnum = XmlField('documentnum')
        self.firstname = XmlField('firstname')
        self.familyname1 = XmlField('familyname1')
        self.familyname2 = XmlField('familyname2')
        self.telephone1 = XmlField('telephone1')
        self.telephone2 = XmlField('telephone2')
        self.fax = XmlField('fax')
        self.email = XmlField('email')
        self.language = XmlField('language')
        self.province = XmlField('province')
        self.city = XmlField('city')
        self.zipcode = XmlField('zipcode')
        self.streettype = XmlField('streettype')
        self.street = XmlField('street')
        self.streetnumber = XmlField('streetnumber')
        self.portal = XmlField('portal')
        self.staircase = XmlField('staircase')
        self.floor = XmlField('floor')
        self.door = XmlField('door')
        self.regularaddress = XmlField('regularaddress')
        self.provinceowner = XmlField('provinceowner')
        self.cityowner = XmlField('cityowner')
        self.zipcodeowner = XmlField('zipcodeowner')
        self.streettypeowner = XmlField('streettypeowner')
        self.streetowner = XmlField('streetowner')
        self.streetnumberowner = XmlField('streetnumberowner')
        self.portalowner = XmlField('portalowner')
        self.staircaseowner = XmlField('staircaseowner')
        self.floorowner = XmlField('floorowner')
        self.doorowner = XmlField('doorowner')
        self.cups = XmlField('cups')
        self.reqqd = XmlField('reqqd')
        self.reqqh = XmlField('reqqh')
        self.reqestimatedqa = XmlField('reqestimatedqa')
        self.reqoutgoingpressure = XmlField('reqoutgoingpressure')
        self.gasusetype = XmlField('gasusetype')
        self.tolltype = XmlField('tolltype')
        self.counterproperty = XmlField('counterproperty')
        self.aptransind = XmlField('aptransind')
        self.aptransnumber = XmlField('aptransnumber')
        self.reig = XmlField('reig')
        self.designpower = XmlField('designpower')
        self.iricertificatedate = XmlField('iricertificatedate')
        self.terminstexist = XmlField('terminstexist')
        self.modeffectdate = XmlField('modeffectdate')
        self.reqactivationdate = XmlField('reqactivationdate')
        self.extrainfo = XmlField('extrainfo')
        self.productlist = ProductList()
        self.registerdoclist = Registerdoclist()
        super(A138, self).__init__('a138', 'a138')


from gestionatr import defs
from gestionatr import defs_gas
import os
from collections import namedtuple
from datetime import datetime

_ROOT = os.path.abspath(os.path.dirname(__file__))


def get_data(path):
    filename = isinstance(path, (list, tuple)) and path[0] or path
    return os.path.join(_ROOT, 'data', filename)


def get_rec_attr(obj, attr, default=None):
    try:
        res = reduce(getattr, attr.split('.'), obj)
    except:
        if default is not None:
            res = default
        else:
            raise
    return res


def get_description(code, table_name):
    table = getattr(defs, table_name, None)
    if not table:
        raise ValueError(
            "The table with the name '{}' doesn't exist".format(table_name)
        )
    res = dict(table).get(code, None)
    if not res:
        raise ValueError(
            "The key '{}' in the table '{}' doesn't exist".format(
                code, table_name
            )
        )
    return res


def rodes(giro):
    """Retorna el nombre de rodes senceres segons el giro
    """
    return len(str(giro)) - 1


def get_description_gas(code, table_name):
    table = getattr(defs_gas, table_name, None)
    if not table:
        raise ValueError(
            "The table with the name '{}' doesn't exist".format(table_name)
        )
    res = dict(table).get(code, None)
    if not res:
        raise ValueError(
            "The key '{}' in the table '{}' doesn't exist".format(
                code, table_name
            )
        )
    return res


ValidationResult = namedtuple('ValidationResult', ['valid', 'error'])


def validate_xml(data, is_gas=False):
    try:
        from gestionatr.input.messages import Message
        m = Message(data)
        m.parse_xml()
        return ValidationResult(True, None)
    except Exception as e:
        try:
            from gestionatr.input.messages import MessageGas
            m = MessageGas(data)
            m.parse_xml()
            return ValidationResult(True, None)
        except Exception as e2:
            if is_gas:
                return ValidationResult(False, u'Invalid File: {0}'.format(str(e2.value)))
            else:
                return ValidationResult(False, u'Invalid File: {0}'.format(str(e.value)))


def repartir_consums_entre_lectures(consums, lectures_xml):
    """
    Sabem repartir en 2 escenaris:
        - Un consum per cada lectura
        - Un consum per X lectures
    NO sabem repartir:
        - Mes de un consum per un nombre diferent de lectures. per exemple 3 consums per 4 lectures
    """
    res = {}
    if len(consums) == len(lectures_xml):
        i = 0
        for l in lectures_xml:
            res[l] = consums[i]
            i += 1
    elif len(consums) == 1:
        periodes = list(set([l.periode for l in lectures_xml]))
        if len(periodes) > 1:
            consum_acumulat = 0
            for l in lectures_xml:
                # Calculem el consum que te aquesta lectura
                consumo_calculado = l.lectura_hasta.lectura + (l.ajuste and l.ajuste.ajuste_por_integrador or 0.0) - l.lectura_desde.lectura
                if consumo_calculado < 0:
                    consumo_calculado += l.gir_comptador
                res[l] = consumo_calculado
                consum_acumulat += consumo_calculado
            if res:
                if consums[0] >= consum_acumulat:
                    res[lectures_xml[0]] += consums[0] - consum_acumulat
                else:
                    a_repartir = abs(consums[0] - consum_acumulat)
                    for l in sorted(res.keys(), key=lambda *a: a[0].periode):
                        if res[l] >= a_repartir:
                            res[l] -= a_repartir
                            break
                        else:
                            a_repartir -= res[l]
                            res[l] = 0

        else:
            if lectures_xml[0].tipus in ['R', 'RC']:
                for l in lectures_xml:
                    res[l] = 0
                res[lectures_xml[0]] = sum(consums)
            else:
                consum = consums[0]
                import math
                parte_decimal, parte_entera = math.modf(consum)
                part_igual = int(parte_entera) / len(lectures_xml)
                residu = (int(parte_entera) % len(lectures_xml)) + parte_decimal

                l = None
                for l in lectures_xml:
                    res[l] = part_igual
                if l:
                    res[l] += residu
    elif len(consums) == 2*len(lectures_xml):
        i = 0
        for l in lectures_xml:
            res[l] = consums[i] + consums[i+len(lectures_xml)]
            i += 1
    return res


# -*- coding: utf-8 -*-

from libcomxml.core import XmlModel, XmlField
from gestionatr.output.messages.base_gas import Heading
from gestionatr.output.messages.sw_a1_41 import Registerdoclist, Registerdoc


# Paso 01
class MensajeA149(XmlModel):
    _sort_order = ('mensaje', 'heading', 'a149')

    def __init__(self):
        self.doc_root = None
        self.mensaje = XmlField(
            'sctdapplication', attributes={'xmlns': 'http://localhost/sctd/A149'}
        )
        self.heading = Heading()
        self.a149 = A149()
        super(MensajeA149, self).__init__('sctdapplication', 'mensaje')


class A149(XmlModel):

    _sort_order = (
        'a149', 'comreferencenum', 'reqdate', 'reqhour', 'cups', 'comreferencenumdes', 'tipodesistimiento',
        'documenttype', 'documentnum', 'titulartype', 'extrainfo'
    )

    def __init__(self):
        self.a149 = XmlField('a149')
        self.comreferencenum = XmlField('comreferencenum')
        self.reqdate = XmlField('reqdate')
        self.reqhour = XmlField('reqhour')
        self.cups = XmlField('cups')
        self.comreferencenumdes = XmlField('comreferencenumdes')
        self.tipodesistimiento = XmlField('tipodesistimiento')
        self.documenttype = XmlField('documenttype')
        self.documentnum = XmlField('documentnum')
        self.titulartype = XmlField('titulartype')
        self.extrainfo = XmlField('extrainfo')

        super(A149, self).__init__('a149', 'a149')

